/***************************************************************************//**
*   @file   main.c
*   @brief  Main File for ADP5589 Driver.
*   @author ATofan (alexandru.tofan@analog.com)
********************************************************************************
* Copyright 2012(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
* IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
* LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
* SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
* CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
* OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
********************************************************************************
*   SVN Revision: $WCREV$
*******************************************************************************/

/*****************************************************************************/
/***************************** Include Files *********************************/
/*****************************************************************************/
#include <stdio.h>
#include "xparameters.h"
#include "xil_cache.h"
#include "xil_io.h"
#include "spi.h"

/******************************************************************************
* @brief Main function.
*
* @return Always returns 0.
******************************************************************************/
int main() 
{
   int RxData;

   Xil_ICacheEnable();
   Xil_DCacheEnable();

   // Initialize SPI Core
   SPI_Init();
   
   xil_printf("PmodGYRO2 Demo Program\n\r");
   // Recommended Start-Up sequence with CHK bit assertion
   // Send Initialization Data to PmodGYRO2
   SPI_TransferData(0x20000003);
   delay_ms(50);
   SPI_TransferData(0x20000000);
   delay_ms(50);
   SPI_TransferData(0x20000000);
   SPI_TransferData(0x20000000);
   
   // Keep reading data from sensor
   // and print it on UART
   while(1)
   {
	   RxData = SPI_TransferData(0x20000000);
	   delay_ms(3);
	   // If data received is valid (Check ST0 and ST1 bits in Status Register)
	   if(((RxData & 0xC000000) == 0x4000000)&&((RxData & 0x00000004) != 0x00000004))
	   {
		   // If data received is in positive degree range
		   if((((RxData & 0x3FFFC00) >> 10) < 0x7FFF)&&(((RxData & 0x3FFFC00) >> 10) > 0x0000))
		   {
			   PrintDegreesPos(((RxData & 0x3FFFC00) >> 10)*125);
		   }
		   // If data received is in negative degree range
		   else if((((RxData & 0x3FFFC00) >> 10) < 0xFFFF)&&(((RxData & 0x3FFFC00) >> 10) > 0x8000))
		   {
			   PrintDegreesPos(((RxData & 0x3FFFC00) >> 10)*125);
		   }
	   }
   }

   Xil_DCacheDisable();
   Xil_ICacheDisable();

   return 0;
}

